@@ -118,25 +118,6 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			message("The response variable is stored in object$data_response ...")
 		},
 		#' @description
-		#' Pre-process (centering, scaling etc.) of the feature data based on the caret::preProcess function. 
-		#' 	 See \href{https://topepo.github.io/caret/pre-processing.html}{https://topepo.github.io/caret/pre-processing.html} for more details.
-		#' 
-		#' @param ... parameters pass to \code{preProcess} function of caret package.
-		#' @return preprocessed \code{data_feature} in the object.
-		#' @examples
-		#' \dontrun{
-		#' # "nzv" removes near zero variance predictors
-		#' t1$cal_preProcess(method = c("center", "scale", "nzv"))
-		#' }
-		cal_preProcess = function(...){
-			raw_feature <- self$data_feature
-			preProcess_res <- caret::preProcess(raw_feature, ...)
-			new_data <- predict(preProcess_res, newdata = raw_feature)
-			self$data_feature <- new_data
-			message("The converted feature table is stored in object$data_feature ...")
-			invisible(self)
-		},
-		#' @description
 		#' Split data for training and testing.
 		#' 
 		#' @param prop.train default 3/4; the ratio of the data used for the training.
@@ -167,6 +148,42 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 			invisible(self)
 		},
 		#' @description
+		#' Pre-process (centering, scaling etc.) of features based on the caret::preProcess function. 
+		#' 	 See \href{https://topepo.github.io/caret/pre-processing.html}{https://topepo.github.io/caret/pre-processing.html} for more details.
+		#' 
+		#' @param ... parameters pass to \code{preProcess} function of caret package.
+		#' @return \code{data_preProcess}, \code{data_train} and \code{data_test} in the object.
+		#' 	 \code{data_preProcess} is the return data generated by the \code{preProcess} function of caret package based on the training data.
+		#' 	 \code{data_train} and \code{data_test} are preprocessed training and testing data based on the \code{data_preProcess}.
+		#' @examples
+		#' \dontrun{
+		#' # "nzv" removes near zero variance predictors
+		#' t1$cal_preProcess(method = c("center", "scale", "nzv"))
+		#' }
+		cal_preProcess = function(...){
+			self <- private$check_training_data(self)
+			data_train <- self$data_train
+			
+			if(is.null(self$data_preProcess)){
+				preProcess_res <- caret::preProcess(data_train[, -1], ...)
+				self$data_preProcess <- preProcess_res
+				message("Preprocess model is stored in object$data_preProcess ...")
+			}else{
+				preProcess_res <- self$data_preProcess
+			}
+			
+			data_train[, -1] <- predict(preProcess_res, newdata = data_train[, -1])
+			self$data_train <- data_train
+			message("Training data is preprocessed and reassigned to object$data_train ...")
+			if(!is.null(self$data_test)){
+				data_test <- self$data_test
+				data_test[, -1] <- predict(preProcess_res, newdata = data_test[, -1])
+				self$data_test <- data_test
+				message("Testing data is preprocessed and reassigned to object$data_test ...")
+			}
+			invisible(self)
+		},
+		#' @description
 		#' Perform feature selection.
 		#' 	 See \href{https://topepo.github.io/caret/feature-selection-overview.html}{https://topepo.github.io/caret/feature-selection-overview.html} for more details.
 		#' 
@@ -174,7 +191,7 @@ trans_classifier <- R6::R6Class(classname = "trans_classifier",
 		#' @param boruta.pValue default 0.01; p value passed to the pValue parameter in \code{Boruta} function of Boruta package.
 		#' @param boruta.repetitions default 4; repetition runs for the feature selection.
 		#' @param ... parameters pass to \code{Boruta} function of Boruta package.
-		#' @return optimized \code{data_feature} in the object.
+		#' @return optimized \code{data_train} and \code{data_test} in the object.
 		#' @examples
 		#' \dontrun{
 		#' t1$cal_feature_sel(boruta.maxRuns = 300, boruta.pValue = 0.01)
