@@ -82,6 +82,8 @@ trans_network <- R6Class(classname = "trans_network",
 				message("Input dataset not provided. Please run the functions with your other customized data!")
 			}else{
 				use_dataset <- clone(dataset)
+				message(ncol(use_dataset$otu_table), " samples and ", nrow(use_dataset$otu_table), " features in the input dataset ...")
+				
 				if(!is.null(env_cols)){
 					env_data <- use_dataset$sample_table[, env_cols, drop = FALSE]
 				}
@@ -105,6 +107,8 @@ trans_network <- R6Class(classname = "trans_network",
 				rel_abund %<>% {. * 100} %>% .[rownames(use_abund)]
 				
 				private$check_filter_number(use_abund, param = "filter_thres")
+				message("After filtering, ", nrow(use_abund), " features are left ...")
+				
 				use_abund %<>% t %>% as.data.frame
 				
 				if((!is.null(cor_method)) & (!is.null(env_cols) | !is.null(add_data))){
@@ -120,7 +124,7 @@ trans_network <- R6Class(classname = "trans_network",
 					if(cor_method %in% c("pearson", "spearman")){
 						if(use_NetCoMi_pearson_spearman){
 							private$check_NetCoMi()
-							netConstruct_raw <- netConstruct(data = use_abund, measure = cor_method, ...)
+							netConstruct_raw <- netConstruct(data = as.matrix(use_abund), measure = cor_method, ...)
 							cor_result <- private$get_cor_p_list(netConstruct_raw$assoMat1)
 						}else{
 							if(use_WGCNA_pearson_spearman){
@@ -134,7 +138,7 @@ trans_network <- R6Class(classname = "trans_network",
 						use_sparcc_method <- match.arg(use_sparcc_method, c("NetCoMi", "SpiecEasi"))
 						if(use_sparcc_method == "NetCoMi"){
 							private$check_NetCoMi()
-							netConstruct_raw <- netConstruct(data = use_abund, measure = cor_method, ...)
+							netConstruct_raw <- netConstruct(data = as.matrix(use_abund), measure = cor_method, ...)
 							cor_result <- private$get_cor_p_list(netConstruct_raw$assoMat1)
 						}else{
 							try_find <- try(find.package("SpiecEasi"), silent = TRUE)
@@ -153,7 +157,7 @@ trans_network <- R6Class(classname = "trans_network",
 					}
 					if(cor_method %in% c("bicor", "cclasso", "ccrepe")){
 						private$check_NetCoMi()
-						netConstruct_raw <- netConstruct(data = use_abund, measure = cor_method, ...)
+						netConstruct_raw <- netConstruct(data = as.matrix(use_abund), measure = cor_method, ...)
 						cor_result <- private$get_cor_p_list(netConstruct_raw$assoMat1)
 					}
 					self$res_cor_p <- cor_result
@@ -200,6 +204,7 @@ trans_network <- R6Class(classname = "trans_network",
 		#' @param COR_p_thres default 0.01; the p value threshold for the correlation-based network.
 		#' @param COR_p_adjust default "fdr"; p value adjustment method, see \code{method} parameter of \code{p.adjust} function for available options,
 		#' 	  in which \code{COR_p_adjust = "none"} means giving up the p value adjustment.
+		#' @param COR_return_padjust default FALSE; Whether to return the adjusted p-value matrix and store it in the object (named \code{res_cor_p$p.adjust}).
 		#' @param COR_weight default TRUE; whether use correlation coefficient as the weight of edges; FALSE represents weight = 1 for all edges.
 		#' @param COR_cut default 0.6; correlation coefficient threshold for the correlation network.
 		#' @param COR_optimization default FALSE; whether use random matrix theory (RMT) based method to determine the correlation coefficient; 
@@ -246,6 +251,7 @@ trans_network <- R6Class(classname = "trans_network",
 			network_method = c("COR", "SpiecEasi", "gcoda", "FlashWeave", "beemStatic")[1],
 			COR_p_thres = 0.01,
 			COR_p_adjust = "fdr",
+			COR_return_padjust = FALSE,
 			COR_weight = TRUE,
 			COR_cut = 0.6,
 			COR_optimization = FALSE,
@@ -296,6 +302,10 @@ trans_network <- R6Class(classname = "trans_network",
 					if(! identical(colnames(cortable), colnames(adp))){
 						adp <- adp[colnames(cortable), colnames(cortable)]
 					}
+					if(COR_return_padjust){
+						self$res_cor_p$p.adjust <- adp
+						message("Adjusted p value matrix is stored in res_cor_p$p.adjust ...")
+					}
 					if(COR_optimization == T){
 						message("Start COR optimizing ...")
 						tc1 <- private$rmt(cortable, low_thres = COR_optimization_low_high[1], high_thres = COR_optimization_low_high[2], seq_by = COR_optimization_seq)
@@ -1321,7 +1331,6 @@ trans_network <- R6Class(classname = "trans_network",
 			if(nrow(input) == 1){
 				stop("After filtering, only one feature is remained! Please try to lower ", param, "!")
 			}
-			message("After filtering, ", nrow(input), " features are remained ...")
 		},
 		check_NetCoMi = function(){
 			if(!require("NetCoMi")){
